#-------------------------------------------------------------------------------
# Name:        output
#-------------------------------------------------------------------------------
#!/usr/bin/env python






#-------------------------------------------------------------------------------
# imports we need
import sys
import os
#-------------------------------------------------------------------------------



#-------------------------------------------------------------------------------
# add parent directory to path
curpath = os.path.dirname(os.path.realpath(__file__))
parpath = os.path.normpath(os.path.join(curpath, ".."))
sys.path.append(parpath)

# import the parent classes
from TOutputFormatter import *
#-------------------------------------------------------------------------------






















#---------------------------------------------------------------------------
class TOutputFormatter_BBCode(TOutputFormatter):

    def __init__(self):
        # parent init
        super(TOutputFormatter_BBCode, self).__init__()

    def __del__(self):
        pass


    def ParseDerivedCommandlineArgs(self):
        # derived parsing
        self.helper.get_parser().add_option("", "--format", dest="format", help="desired output format, from BBCODE|HTML|WIKI|PLAIN (defaults to BBCODE)")
        self.helper.get_parser().add_option("", "--hlist", action="store_true", dest="hlist", help="if present this flag says to put headers in a top level list")
        self.helper.get_parser().add_option("", "--hrlink", action="store_true", dest="hrlink", help="if present this flag says to make headers absorb first result at link")
        self.helper.get_parser().add_option("", "--hrtitle", action="store_true", dest="hrtitle", help="if present this flag says to make headers use title of first result")
        self.helper.get_parser().add_option("", "--nolabels", action="store_true", dest="nolabels", help="if present this flag says to just show urls, no labels")
        self.helper.get_parser().add_option("", "--rmax", dest="rmax", help="optional; limit to this many results under each group header (0 for none, dont pass for all)")

    def PostParseDerivedCommandlineArgs(self):
        # now we can look at any parsed commandline options
        self.format = self.helper.get_arg("format","BBCODE",False).upper()

        if (self.format=='BBCODE'):
            self.out_liststart="[list]"
            self.out_listend="[/list]\n\n"
            self.out_listitemstart="[li]"
            self.out_listitemend="[/li]"
            self.outputformatcode = "BBCODE"
        elif (self.format=='WIKI'):
            self.out_liststart=""
            self.out_listend="\n\n"
            self.out_listitemstart="* "
            self.out_listitemend=""
            self.outputformatcode = "MARKDOWN"
        elif (self.format=='PLAIN'):
            self.out_liststart=""
            self.out_listend="\n\n"
            self.out_listitemstart="  "
            self.out_listitemend=""
            self.outputformatcode = "PLAINTEXT"
        else:
            self.out_liststart="<ul>"
            self.out_listend="</ul>\n\n"
            self.out_listitemstart="<li>"
            self.out_listitemend="</li>"
            self.outputformatcode = "HTML"






    def makeurllink(self,url,label):
        nolabels = int(self.helper.get_arg("nolabels",False,False))
        if (nolabels):
            label=url

        if (self.format=='BBCODE'):
            return "[url="+self.SafeifyBBCode(url)+"]"+self.SafeifyBBCode(label)+"[/url]"
        elif (self.format=='WIKI'):
            if (url==label or label==""):
                return "["+self.helper.urlquoteconservatively(url)+"]"
            else:
                return "["+self.helper.urlquoteconservatively(url)+" "+label+"]"
        elif (self.format=='PLAIN' or nolabels):
            if (url==label or label=="" or nolabels):
                return url
            else:
                return label+" - "+url
        else:
            return "<a href=\""+url+"\">"+label+"</a>"




    def SafeifyBBCode(self,str):
        # remove any []
        str = str.replace("[","(")
        str = str.replace("]",")")
        return str



    def DoOutput_GroupHeader(self,outfile,resultgroup):
        if len(resultgroup)==0:
            return;
        # settings

        hlist = self.helper.get_arg("hlist",False,False)
        hrlink = self.helper.get_arg("hrlink",False,False)
        hrtitle = self.helper.get_arg("hrtitle",False,False)
        rmax = int(self.helper.get_arg("rmax",9999,False))

        #label of this group
        if "label" in resultgroup[0]:
            label=resultgroup[0]["label"]
        else:
            label=""
        # specialsettings
        if (hrtitle and "linktitle" in resultgroup[0]):
            label=resultgroup[0]["linktitle"]
        if (hrlink and "url" in resultgroup[0]):
            url=resultgroup[0]["url"]
        else:
            url=""
        #
        if label != "":
            outstring=""
            if (hlist):
                outstring=outstring+self.out_listitemstart
            if (url==""):
                outstring=outstring+label
            else:
                outstring=outstring+self.makeurllink(url,label)
            if (rmax>0):
                outstring=outstring+":"
            if (hlist):
                outstring=outstring+self.out_listitemend
            outfile.write(outstring+"\n")
        # start the list for children
        if (rmax>0):
            outfile.write(self.out_liststart+"\n")


    def DoOutput_GroupFooter(self,outfile,resultgroup):
        if len(resultgroup)==0:
            return;
        rmax = int(self.helper.get_arg("rmax",9999,False))
        # end the list
        if (rmax>0):
            outfile.write(self.out_listend)
        #outfile.write("\n")


    def DoOutput_Result(self,outfile,resultgroup,result):
        # start list
        outfile.write(self.out_listitemstart)
        #
        if ("url" in result):
            url=result["url"]
        else:
            url=""
        if ("linktitle" in result):
            linktitle=result["linktitle"]
        else:
            linktitle=""
        # output
        if (url!="") and (linktitle!=""):
            outfile.write(self.makeurllink(url,linktitle))
        elif url!="":
            outfile.write(self.makeurllink(url,url))
        elif linktitle!="":
            outfile.write(linktitle)
        # end list
        outfile.write(self.out_listitemend+"\n")




    def DoOutput_Group(self,outfile,resultgroup):
        # settings
        hlist = self.helper.get_arg("hlist",False,False)
        hrlink = self.helper.get_arg("hrlink",False,False)
        hrtitle = self.helper.get_arg("hrtitle",False,False)
        rmax = int(self.helper.get_arg("rmax",9999,False))
        #
        self.DoOutput_GroupHeader(outfile,resultgroup)
        resultcount=0
        for result in resultgroup:
            if (resultcount>=rmax):
                break
            resultcount = resultcount+1
            if (resultcount==1 and hrlink):
                continue
            self.DoOutput_Result(outfile,resultgroup,result)
        self.DoOutput_GroupFooter(outfile,resultgroup)




    def DoOutput_AllHeader(self,outfile,groupcount):
        # settings
        hlist = self.helper.get_arg("hlist",False,False)
        if (hlist):
            outfile.write(self.out_liststart+"\n")
        pass


    def DoOutput_AllFooter(self,outfile,groupcount):
        # settings
        hlist = self.helper.get_arg("hlist",False,False)
        if (hlist):
            outfile.write(self.out_listend+"\n")
        pass
#---------------------------------------------------------------------------












































#---------------------------------------------------------------------------
def main(comlineargs=None):
    # make object
    outputter = TOutputFormatter_BBCode()

    # and ask it to run with commandline options
    return outputter.RunWithCommandlineOptions(comlineargs)
#---------------------------------------------------------------------------






#-------------------------------------------------------------------------------
if __name__ == '__main__':
    main()
#-------------------------------------------------------------------------------


